@@ -353,7 +353,7 @@ void KStandardItemListWidget::paint(QPainter *painter, const QStyleOptionGraphic
         const KItemListStyleOption &option = styleOption();
         const qreal padding = option.padding;
 
-        const int widgetIconSize = iconSize();
+        const int widgetIconSize = styleOption().iconSize;
         const int maxIconWidth = iconOnTop ? size().width() - 2 * padding : widgetIconSize;
         const int maxIconHeight = widgetIconSize;
 
@@ -572,7 +572,7 @@ QRectF KStandardItemListWidget::selectionToggleRect() const
 {
     const_cast<KStandardItemListWidget *>(this)->triggerCacheRefreshing();
 
-    const int widgetIconSize = iconSize();
+    const int widgetIconSize = styleOption().iconSize;
     int toggleSize = KIconLoader::SizeSmall;
     if (widgetIconSize >= KIconLoader::SizeEnormous) {
         toggleSize = KIconLoader::SizeMedium;
@@ -867,8 +867,6 @@ void KStandardItemListWidget::editedRoleChanged(const QByteArray &current, const
 
     Q_ASSERT(!m_roleEditor);
 
-    const TextInfo *textInfo = m_textInfo.value("text");
-
     m_roleEditor = new KItemListRoleEditor(parent);
     m_roleEditor->setRole(current);
     m_roleEditor->setAllowUpDownKeyChainEdit(m_layout != IconsLayout);
@@ -877,8 +875,11 @@ void KStandardItemListWidget::editedRoleChanged(const QByteArray &current, const
     const QString text = data().value(current).toString();
     m_roleEditor->setPlainText(text);
 
-    QTextOption textOption = textInfo->staticText.textOption();
-    m_roleEditor->document()->setDefaultTextOption(textOption);
+    const TextInfo *textInfo = m_textInfo.value("text");
+    if (textInfo) {
+        QTextOption textOption = textInfo->staticText.textOption();
+        m_roleEditor->document()->setDefaultTextOption(textOption);
+    }
 
     const int textSelectionLength = selectionLength(text);
 
@@ -1024,7 +1025,7 @@ void KStandardItemListWidget::updateExpansionArea()
         const QHash<QByteArray, QVariant> values = data();
         const int expandedParentsCount = values.value("expandedParentsCount", 0).toInt();
         if (expandedParentsCount >= 0) {
-            const int widgetIconSize = iconSize();
+            const int widgetIconSize = styleOption().iconSize;
             const qreal widgetHeight = size().height();
             const qreal inc = (widgetHeight - widgetIconSize) / 2;
             const qreal x = expandedParentsCount * widgetHeight + inc;
@@ -1054,7 +1055,7 @@ void KStandardItemListWidget::updatePixmapCache()
     const qreal padding = option.padding;
     const qreal dpr = KItemViewsUtils::devicePixelRatio(this);
 
-    const int widgetIconSize = iconSize();
+    const int widgetIconSize = option.iconSize;
     const int maxIconWidth = iconOnTop ? widgetSize.width() - 2 * padding : widgetIconSize;
     const int maxIconHeight = widgetIconSize;
 
@@ -1336,7 +1337,7 @@ void KStandardItemListWidget::updateIconsLayoutTextCache()
                     const QString elidedText = nameText.left(line.textStart()) + lastTextLine;
                     nameTextInfo->staticText.setText(elidedText);
 
-                    lastLineWidth = m_customizedFontMetrics.boundingRect(lastTextLine).width();
+                    lastLineWidth = m_customizedFontMetrics.size(0, lastTextLine).width();
 
                     // We do the text eliding in a loop with decreasing width (1 px / iteration)
                     // to avoid problems related to different width calculation code paths
@@ -1353,7 +1354,7 @@ void KStandardItemListWidget::updateIconsLayoutTextCache()
 
     // Use one line for each additional information
     nameTextInfo->staticText.setTextWidth(maxWidth);
-    nameTextInfo->pos = QPointF(padding, iconSize() + 2 * padding);
+    nameTextInfo->pos = QPointF(padding, styleOption().iconSize + 2 * padding);
     m_textRect = QRectF(padding + (maxWidth - nameWidth) / 2, nameTextInfo->pos.y(), nameWidth, nameHeight);
 
     // Calculate the position for each additional information
@@ -1421,9 +1422,9 @@ void KStandardItemListWidget::updateCompactLayoutTextCache()
     const qreal textLinesHeight = qMax(visibleRoles().count(), 1) * lineSpacing;
 
     qreal maximumRequiredTextWidth = 0;
-    const qreal x = QApplication::isRightToLeft() ? option.padding : option.padding * 3 + iconSize();
+    const qreal x = QApplication::isRightToLeft() ? option.padding : option.padding * 3 + styleOption().iconSize;
     qreal y = qRound((widgetHeight - textLinesHeight) / 2);
-    const qreal maxWidth = size().width() - iconSize() - 4 * option.padding;
+    const qreal maxWidth = size().width() - styleOption().iconSize - 4 * option.padding;
     for (const QByteArray &role : std::as_const(m_sortedVisibleRoles)) {
         const QString text = escapeString(roleText(role, values));
         TextInfo *textInfo = m_textInfo.value(role);
@@ -1471,7 +1472,7 @@ void KStandardItemListWidget::updateDetailsLayoutTextCache()
     const int fontHeight = m_customizedFontMetrics.height();
 
     const qreal columnWidthInc = columnPadding(option);
-    qreal firstColumnInc = iconSize();
+    qreal firstColumnInc = styleOption().iconSize;
     if (m_supportsItemExpanding) {
         firstColumnInc += isLeftToRight ? (m_expansionArea.left() + m_expansionArea.right() + widgetHeight) / 2
                                         : ((size().width() - m_expansionArea.left()) + (size().width() - m_expansionArea.right()) + widgetHeight) / 2;
@@ -1550,7 +1551,7 @@ void KStandardItemListWidget::updateAdditionalInfoTextColor()
 QPixmap
 KStandardItemListWidget::addOverlays(const QPixmap &pixmap, const QHash<Qt::Corner, QString> &overlays, const QSize &size, qreal dpr, QIcon::Mode mode) const
 {
-    // similar to KIconUtils::addOverlays, keep in sync preferrably
+    // similar to KIconUtils::addOverlays, keep in sync preferably
     if (overlays.isEmpty()) {
         return pixmap;
     }
