@@ -81,14 +81,22 @@ InformationPanelContent::InformationPanelContent(QWidget *parent)
     connect(m_mediaWidget, &MediaWidget::hasVideoChanged, this, &InformationPanelContent::slotHasVideoChanged);
 
     // name
-    m_nameLabel = new QLabel(parent);
+    m_nameLabel = new QTextEdit(parent);
     QFont font = m_nameLabel->font();
     font.setBold(true);
     m_nameLabel->setFont(font);
-    m_nameLabel->setTextFormat(Qt::PlainText);
     m_nameLabel->setAlignment(Qt::AlignHCenter);
     m_nameLabel->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed);
     m_nameLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
+    m_nameLabel->setFrameShape(QFrame::NoFrame);
+    m_nameLabel->setStyleSheet("background-color: transparent; padding: 0px;");
+    m_nameLabel->setContentsMargins(0, 0, 0, 0); 
+    m_nameLabel->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    m_nameLabel->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    QTextDocument *doc = m_nameLabel->document();
+    QTextOption option = doc->defaultTextOption();
+    option.setWrapMode(QTextOption::WrapAnywhere);
+    doc->setDefaultTextOption(option);
 
     const bool previewsShown = InformationPanelSettings::previewsShown();
     m_preview->setVisible(previewsShown);
@@ -164,6 +172,9 @@ void InformationPanelContent::refreshPixmapView()
         m_previewJob->kill();
     }
 
+    // Reset disabled state when starting a new preview job
+    m_disabledPreviewUrl.clear();
+
     // try to get a preview pixmap from the item...
 
     // Mark the currently shown preview as outdated. This is done
@@ -354,6 +365,7 @@ void InformationPanelContent::showIcon(const KFileItem &item)
     QPixmap pixmap = KIconUtils::addOverlays(icon, item.overlays()).pixmap(m_preview->size(), devicePixelRatioF());
     pixmap.setDevicePixelRatio(devicePixelRatioF());
     m_preview->setPixmap(pixmap);
+    m_disabledPreviewUrl.clear();
 }
 
 void InformationPanelContent::showPreview(const KFileItem &item, const QPixmap &pixmap)
@@ -426,9 +438,17 @@ void InformationPanelContent::markOutdatedPreview()
         // use it until the preview is done
         showIcon(m_item);
     } else {
+        // Only apply disabled effect once per URL to avoid repeated brightening
+        if (m_disabledPreviewUrl == m_item.url()) {
+            return;
+        }
+        m_disabledPreviewUrl = m_item.url();
+
         QPixmap disabledPixmap = m_preview->pixmap();
-        KIconEffect::toDisabled(disabledPixmap);
-        m_preview->setPixmap(disabledPixmap);
+        if (!disabledPixmap.isNull()) {
+            KIconEffect::toDisabled(disabledPixmap);
+            m_preview->setPixmap(disabledPixmap);
+        }
     }
 }
 
@@ -459,28 +479,9 @@ void InformationPanelContent::setNameLabelText(const QString &text)
 
     const QString processedText = Qt::mightBeRichText(text) ? text : KStringHandler::preProcessWrap(text);
 
-    QTextLayout textLayout(processedText);
-    textLayout.setFont(m_nameLabel->font());
-    textLayout.setTextOption(textOption);
-
-    QString wrappedText;
-    wrappedText.reserve(processedText.length());
-
-    // wrap the text to fit into the width of m_nameLabel
-    textLayout.beginLayout();
-    QTextLine line = textLayout.createLine();
-    while (line.isValid()) {
-        line.setLineWidth(m_nameLabel->width());
-        wrappedText += QStringView(processedText).mid(line.textStart(), line.textLength());
-
-        line = textLayout.createLine();
-        if (line.isValid()) {
-            wrappedText += QChar::LineSeparator;
-        }
-    }
-    textLayout.endLayout();
-
-    m_nameLabel->setText(wrappedText);
+    m_nameLabel->setText(processedText);
+    m_nameLabel->setFixedHeight(m_nameLabel->document()->size().height());
+    m_nameLabel->setAlignment(Qt::AlignHCenter);
 }
 
 void InformationPanelContent::adjustWidgetSizes(int width)
@@ -500,8 +501,10 @@ void InformationPanelContent::adjustWidgetSizes(int width)
     // try to increase the preview as large as possible
     m_preview->setSizeHint(QSize(maxWidth, maxWidth));
 
-    // assure that the size of the video player is the same as the preview size
-    m_mediaWidget->setVideoSize(QSize(maxWidth, maxWidth));
+    if (m_mediaWidget->isVisible()) {
+        // assure that the size of the video player is the same as the preview size
+        m_mediaWidget->setVideoSize(QSize(maxWidth, maxWidth));
+    }
 }
 
 #include "moc_informationpanelcontent.cpp"
