@@ -44,10 +44,12 @@
 #include <KIO/Paste>
 #include <KIO/PasteJob>
 #include <KIO/RenameFileDialog>
+#include <KIconUtils>
 #include <KJob>
 #include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KMessageDialog>
 #include <KProtocolManager>
 #include <KUrlMimeData>
 
@@ -485,6 +487,13 @@ void DolphinView::setSortRole(const QByteArray &role)
         ViewProperties props(viewPropertiesUrl());
         props.setSortRole(role);
 
+        const Qt::SortOrder preferredOrder = preferredSortOrder(role);
+        if (sortOrder() != preferredOrder) {
+            props.setSortOrder(preferredOrder);
+            KItemModelBase *model = m_container->controller()->model();
+            model->setSortOrder(preferredOrder);
+        }
+
         KItemModelBase *model = m_container->controller()->model();
         model->setSortRole(role);
 
@@ -1732,6 +1741,31 @@ QUrl DolphinView::openItemAsFolderUrl(const KFileItem &item, const bool browseTh
     return QUrl();
 }
 
+Qt::SortOrder DolphinView::defaultSortOrderForRole(const QByteArray &role)
+{
+    static const QSet<QByteArray> descendingRoles = {// Time-based roles
+                                                     "modificationtime",
+                                                     "creationtime",
+                                                     "accesstime",
+                                                     "deletiontime",
+                                                     "imageDateTime",
+                                                     "releaseYear",
+                                                     // Size/dimension roles
+                                                     "size",
+                                                     "width",
+                                                     "height",
+                                                     "pageCount",
+                                                     "wordCount",
+                                                     "lineCount",
+                                                     // Quality/Quantity roles
+                                                     "rating",
+                                                     "duration",
+                                                     "bitrate",
+                                                     "frameRate"};
+
+    return descendingRoles.contains(role) ? Qt::DescendingOrder : Qt::AscendingOrder;
+}
+
 void DolphinView::resetZoomLevel()
 {
     ViewModeSettings settings{m_mode};
@@ -1750,8 +1784,10 @@ void DolphinView::observeCreatedItem(const QUrl &url)
 void DolphinView::slotDirectoryRedirection(const QUrl &oldUrl, const QUrl &newUrl)
 {
     if (oldUrl.matches(url(), QUrl::StripTrailingSlash)) {
-        Q_EMIT redirection(oldUrl, newUrl);
+        // Update the view's URL before emitting signals.
         m_url = newUrl; // #186947
+
+        Q_EMIT redirection(oldUrl, newUrl);
     }
 }
 
@@ -1897,14 +1933,10 @@ void DolphinView::selectNextItem()
             Q_ASSERT_X(false, "DolphinView", "Selecting the next item failed.");
             return;
         }
-        auto nextItem = lastSelectedIndex + 1;
-        if (nextItem >= itemsCount()) {
-            nextItem = lastSelectedIndex - selectedItemsCount();
-        }
-        if (nextItem >= 0) {
-            selectionManager->setSelected(nextItem, 1);
-            selectionManager->beginAnchoredSelection(nextItem);
-        }
+        const auto nextItem = qMin(lastSelectedIndex + 1, itemsCount() - 1);
+        selectionManager->setCurrentItem(nextItem);
+        selectionManager->clearSelection();
+
         m_selectNextItem = false;
     }
 }
@@ -1951,14 +1983,14 @@ void DolphinView::slotDirectoryLoadingCompleted()
     // because the view might not be in its final state yet.
     QTimer::singleShot(0, this, &DolphinView::updateViewState);
 
+    applyDynamicView();
+
     // Update the placeholder label in case we found that the folder was empty
     // after loading it
-
-    Q_EMIT directoryLoadingCompleted();
-
-    applyDynamicView();
     updatePlaceholderLabel();
     updateWritableState();
+
+    Q_EMIT directoryLoadingCompleted();
 }
 
 void DolphinView::slotDirectoryLoadingCanceled()
@@ -1980,6 +2012,9 @@ void DolphinView::slotSortOrderChangedByHeader(Qt::SortOrder current, Qt::SortOr
     Q_UNUSED(previous)
     Q_ASSERT(m_model->sortOrder() == current);
 
+    const QByteArray currentRole = m_model->sortRole();
+    m_rolesSortOrder[currentRole] = current;
+
     ViewProperties props(viewPropertiesUrl());
     props.setSortOrder(current);
 
@@ -1994,6 +2029,13 @@ void DolphinView::slotSortRoleChangedByHeader(const QByteArray &current, const Q
     ViewProperties props(viewPropertiesUrl());
     props.setSortRole(current);
 
+    const Qt::SortOrder preferredOrder = preferredSortOrder(current);
+    if (m_model->sortOrder() != preferredOrder) {
+        props.setSortOrder(preferredOrder);
+        m_model->setSortOrder(preferredOrder);
+        Q_EMIT sortOrderChanged(preferredOrder);
+    }
+
     Q_EMIT sortRoleChanged(current);
 }
 
@@ -2055,8 +2097,54 @@ void DolphinView::slotRoleEditingFinished(int index, const QByteArray &role, con
                 if (code == KMessageBox::SecondaryAction) {
                     return;
                 }
-            }
+            } else
 #endif
+                // Confirm potentially changing the file type.
+                if (GeneralSettings::confirmRenameFileType() && oldItem.isFile() && oldItem.isLocalFile() && !oldItem.isSlow() && oldItem.isMimeTypeKnown()) {
+                    QMimeDatabase db;
+                    const QMimeType oldMimeType = db.mimeTypeForName(oldItem.mimetype());
+
+                    // Guess what the new file type would be.
+                    // We have to also read the file as its new type could be auto-determined from content.
+                    QFile oldFile(oldItem.localPath());
+                    const QMimeType newMimeType = db.mimeTypeForFileNameAndData(newName, &oldFile);
+
+                    if (oldMimeType.isValid() && !oldMimeType.isDefault() && newMimeType.isValid() && newMimeType != oldMimeType) {
+                        const KGuiItem yesGuiItem(i18nc("@action:button", "Rename"), QStringLiteral("edit-rename"));
+
+                        const QIcon mimeTypeIcon = QIcon::fromTheme(newMimeType.iconName(), QIcon::fromTheme(QStringLiteral("unknown")));
+                        // emblem-warning is non-standard, fall back to emblem-important if necessary.
+                        const QIcon warningBadge = QIcon::fromTheme(QStringLiteral("emblem-warning"), QIcon::fromTheme(QStringLiteral("emblem-important")));
+
+                        const QIcon messageBoxIcon =
+                            KIconUtils::addOverlay(mimeTypeIcon, warningBadge, isRightToLeft() ? Qt::BottomLeftCorner : Qt::BottomRightCorner);
+
+                        const QString prompt = newMimeType.isDefault() ? i18n(
+                                                                             "This will make the file type unknown.\n"
+                                                                             "The file's content won't change but applications may no longer recognize it.\n"
+                                                                             "Do you still want to rename it?")
+                                                                       : i18n(
+                                                                             "This will change the file type from \"%1\" to \"%2\".\n"
+                                                                             "The file's content won't change but applications may no longer recognize it.\n"
+                                                                             "Do you still want to rename it?",
+                                                                             oldMimeType.comment(),
+                                                                             newMimeType.comment());
+                        auto *dialog = new KMessageDialog(KMessageDialog::QuestionTwoActions, prompt, this);
+                        dialog->setWindowTitle(i18nc("@title:window", "Change File Type"));
+                        dialog->setButtons(yesGuiItem, KStandardGuiItem::cancel());
+                        dialog->setIcon(messageBoxIcon);
+                        dialog->setDontAskAgainText(i18n("Do not ask again"));
+
+                        if (dialog->exec() != KMessageDialog::PrimaryAction) {
+                            return;
+                        }
+
+                        if (dialog->isDontAskAgainChecked()) {
+                            GeneralSettings::setConfirmRenameFileType(false);
+                            GeneralSettings::self()->save();
+                        }
+                    }
+                }
 
             KIO::Job *job = KIO::moveAs(oldUrl, newUrl);
             KJobWidgets::setWindow(job, this);
@@ -2245,7 +2333,11 @@ void DolphinView::applyDynamicView()
 
     for (const auto &file : itemList) {
         ++checkedItems;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
         const QString type = file.mimetype().slice(0, 5);
+#else
+        const QString type = file.mimetype().sliced(0, 5);
+#endif
 
         if (type == "image" || type == "video") {
             ++imageAndVideoCount;
@@ -2462,7 +2554,7 @@ void DolphinView::updatePlaceholderLabel()
 
     } else if (m_url.scheme() == QLatin1String("recentlyused")) {
         m_placeholderLabel->setText(i18n("No recently used items"));
-    } else if (m_url.scheme() == QLatin1String("smb")) {
+    } else if (m_url.scheme() == QLatin1String("smb") && (m_url.host().isEmpty() || m_url.path().isEmpty() || m_url.path() == QLatin1String("/"))) {
         m_placeholderLabel->setText(i18n("No shared folders found"));
     } else if (m_url.scheme() == QLatin1String("network")) {
         m_placeholderLabel->setText(i18n("No relevant network resources found"));
@@ -2507,4 +2599,18 @@ bool DolphinView::tryShowNameToolTip(QHelpEvent *event)
     return false;
 }
 
+Qt::SortOrder DolphinView::preferredSortOrder(const QByteArray &role) const
+{
+    if (m_rolesSortOrder.contains(role)) {
+        return m_rolesSortOrder.value(role);
+    } else {
+        return defaultSortOrderForRole(role);
+    }
+}
+
+void DolphinView::setPreferredSortOrder(const QByteArray &role, Qt::SortOrder order)
+{
+    m_rolesSortOrder[role] = order;
+}
+
 #include "moc_dolphinview.cpp"
