@@ -233,6 +233,18 @@ public:
     /** Returns the additional information which should be shown for the items. */
     QList<QByteArray> visibleRoles() const;
 
+    /**
+     * Returns the preferred sort order for a given role, taking into account
+     * user preferences and default sort orders.
+     */
+    Qt::SortOrder preferredSortOrder(const QByteArray &role) const;
+
+    /**
+     * Sets the preferred sort order for a given role. This remembers user
+     * preferences when switching between different sort roles.
+     */
+    void setPreferredSortOrder(const QByteArray &role, Qt::SortOrder order);
+
     /**
      * Refreshes the view to get synchronized with the settings (e.g. icons size,
      * font, ...).
@@ -336,6 +348,13 @@ public:
      */
     static QUrl openItemAsFolderUrl(const KFileItem &item, const bool browseThroughArchives = true);
 
+    /**
+     * Set the default order for a given sort role.
+     * Time-based roles, size/dimension roles, and quality/quantity roles
+     * default to descending order. All other roles default to ascending order.
+     */
+    static Qt::SortOrder defaultSortOrderForRole(const QByteArray &role);
+
     /**
      * Hides tooltip displayed over element.
      */
@@ -988,6 +1007,9 @@ private:
     /// Used for selection mode. @see setSelectionMode()
     std::unique_ptr<QProxyStyle> m_proxyStyle;
 
+    /// Hash table of user-preferred sort orders for each role
+    QHash<QByteArray, Qt::SortOrder> m_rolesSortOrder;
+
     // For unit tests
     friend class TestBase;
     friend class DolphinDetailsViewTest;
