@@ -17,6 +17,7 @@
 #if HAVE_BALOO
 #include <Baloo/IndexerConfig>
 #endif
+#include <KActionCategory>
 #include <KActionCollection>
 #include <KActionMenu>
 #include <KFileItemListProperties>
@@ -26,6 +27,7 @@
 #include <KProtocolManager>
 
 #include <QActionGroup>
+#include <QApplication>
 #include <QMenu>
 #include <QPointer>
 
@@ -374,6 +376,8 @@ void DolphinViewActionHandler::createActions(SelectionMode::ActionTextHelper *ac
     viewSettings->addAction(adjustViewProps);
     viewSettings->setPopupMode(QToolButton::ToolButtonPopupMode::MenuButtonPopup);
     connect(viewSettings, &KActionMenu::triggered, viewModeActions, &KSelectAction::triggered);
+    // HACK KActionMenu doesn't set a parent for its menu() causing accessibility traversal issues
+    viewSettings->menu()->setParent(QApplication::activeWindow());
 }
 
 QActionGroup *DolphinViewActionHandler::createFileItemRolesActionGroup(const QString &groupPrefix)
@@ -383,10 +387,13 @@ QActionGroup *DolphinViewActionHandler::createFileItemRolesActionGroup(const QSt
 
     QActionGroup *rolesActionGroup = new QActionGroup(m_actionCollection);
     rolesActionGroup->setExclusive(isSortGroup);
+    KActionCategory *category;
     if (isSortGroup) {
         connect(rolesActionGroup, &QActionGroup::triggered, this, &DolphinViewActionHandler::slotSortTriggered);
+        category = new KActionCategory(i18nc("item:intable", "Sort By field"), m_actionCollection);
     } else {
         connect(rolesActionGroup, &QActionGroup::triggered, this, &DolphinViewActionHandler::toggleVisibleRole);
+        category = new KActionCategory(i18nc("item:intable", "Show Field"), m_actionCollection);
     }
 
     QString groupName;
@@ -409,12 +416,12 @@ QActionGroup *DolphinViewActionHandler::createFileItemRolesActionGroup(const QSt
         KToggleAction *action = nullptr;
         const QString name = groupPrefix + info.role;
         if (info.group.isEmpty()) {
-            action = m_actionCollection->add<KToggleAction>(name);
+            action = category->add<KToggleAction>(name);
             action->setActionGroup(rolesActionGroup);
         } else {
             if (!groupMenu || info.group != groupName) {
                 groupName = info.group;
-                groupMenu = m_actionCollection->add<KActionMenu>(groupName);
+                groupMenu = category->add<KActionMenu>(groupName);
                 groupMenu->setText(groupName);
                 groupMenu->setActionGroup(rolesActionGroup);
 
@@ -431,7 +438,8 @@ QActionGroup *DolphinViewActionHandler::createFileItemRolesActionGroup(const QSt
             action->setActionGroup(groupMenuGroup);
             groupMenu->addAction(action);
         }
-        action->setText(info.translation);
+        action->setText(isSortGroup ? i18nc("@action:intoolbar as in sort by file attribute", "Sort By: %1", info.translation)
+                                    : i18nc("@action:intoolbar as in show field for file attribute", "Show Field: %1", info.translation));
         action->setData(info.role);
 
         const bool enable = (!info.requiresBaloo && !info.requiresIndexer) || (info.requiresBaloo) || (info.requiresIndexer && indexingEnabled);
@@ -594,6 +602,8 @@ void DolphinViewActionHandler::slotSortOrderChanged(Qt::SortOrder order)
     const bool sortDescending = (order == Qt::DescendingOrder);
     descending->setChecked(sortDescending);
     ascending->setChecked(!sortDescending);
+    const QByteArray currentRole = m_currentView->sortRole();
+    m_currentView->setPreferredSortOrder(currentRole, order);
 }
 
 void DolphinViewActionHandler::slotSortFoldersFirstChanged(bool foldersFirst)
@@ -723,13 +733,13 @@ void DolphinViewActionHandler::slotSortRoleChanged(const QByteArray &role)
     if (role == "text" || role == "type" || role == "extension" || role == "tags" || role == "comment") {
         descending->setText(i18nc("Sort descending", "Z-A"));
         ascending->setText(i18nc("Sort ascending", "A-Z"));
-    } else if (role == "size") {
+    } else if (role == "size" || role == "width" || role == "height" || role == "pageCount" || role == "wordCount" || role == "lineCount") {
         descending->setText(i18nc("Sort descending", "Largest First"));
         ascending->setText(i18nc("Sort ascending", "Smallest First"));
-    } else if (role == "modificationtime" || role == "creationtime" || role == "accesstime") {
+    } else if (role == "modificationtime" || role == "creationtime" || role == "accesstime" || role == "imageDateTime" || role == "releaseYear") {
         descending->setText(i18nc("Sort descending", "Newest First"));
         ascending->setText(i18nc("Sort ascending", "Oldest First"));
-    } else if (role == "rating") {
+    } else if (role == "rating" || role == "bitrate" || role == "frameRate") {
         descending->setText(i18nc("Sort descending", "Highest First"));
         ascending->setText(i18nc("Sort ascending", "Lowest First"));
     } else {
